@@ -284,6 +284,17 @@ class SMTSecurityService extends SMTService implements SMTIService
 	    	SMTLogger::getInstance()->traceException($e);
 	    }
 	    
+	    try
+	    {
+	    	$name= $this->sendReceive( SMTOtuApi::CMD_get_otu_name);
+	    	$init->setName($name);
+	    }
+	    catch ( \Exception $e )
+	    {
+	    	//don't throw exception, either SmartOTU will not be initialized
+	    	SMTLogger::getInstance()->traceException($e);
+	    }
+	    
 	    try 
 	    {
 	    	//force local mode retrieve
