@@ -11,7 +11,7 @@ namespace Luracast\Restler\Format;
  * @copyright  2010 Luracast
  * @license    http://www.opensource.org/licenses/lgpl-license.php LGPL
  * @link       http://luracast.com/products/restler/
- * @version    3.0.0rc4
+ * @version    3.0.0rc5
  */
 class JsFormat extends JsonFormat
 {
@@ -33,11 +33,16 @@ class JsFormat extends JsonFormat
             }
         }
         $r['data'] = $data;
-        if ($_GET[static::$callbackOverrideQueryString]) {
+        if (isset($_GET[static::$callbackOverrideQueryString])) {
             static::$callbackMethodName
-                = $_GET[static::$callbackOverrideQueryString];
+                = (string) $_GET[static::$callbackOverrideQueryString];
         }
         return static::$callbackMethodName . '('
             . parent::encode($r, $human_readable) . ');';
     }
+
+    public function isReadable()
+    {
+        return false;
+    }
 }
